@@ -3,3 +3,5 @@ from ._version import __version_info__, __version__
 from .connection import Config, Connection
 from .runners import Remote, Result
 from .group import Group, SerialGroup, ThreadingGroup, GroupResult
+from .tasks import task, Task
+from .executor import Executor
