@@ -25,6 +25,14 @@ class Executor(invoke.Executor):
         """
         Normalize mixed host-strings-or-kwarg-dicts into kwarg dicts only.
 
+        In other words, transforms data taken from the CLI (--hosts, always
+        strings) or decorator arguments (may be strings or kwarg dicts) into
+        kwargs suitable for creating Connection instances.
+
+        Subclasses may wish to override or extend this to perform, for example,
+        database or custom config file lookups (vs this default behavior, which
+        is to simply assume that strings are 'host' kwargs).
+
         :param hosts:
             Potentially heterogenous list of host connection values, as per the
             ``hosts`` param to `.task`.
@@ -80,10 +88,7 @@ class Executor(invoke.Executor):
                 )
 
             def anonymous(c):
-                # TODO: how to make all our tests configure in_stream=False?
-                # TODO: doesn't this preclude users wanting to submit stdin to
-                # remainder commands?
-                c.run(self.core.remainder, in_stream=False)
+                c.run(self.core.remainder)
 
             anon = Call(Task(body=anonymous))
             # TODO: see above TODOs about non-parameterized setups, roles etc
