@@ -23,10 +23,6 @@ class Fab(Program):
     def core_args(self):
         core_args = super(Fab, self).core_args()
         my_args = [
-            Argument(
-                names=("S", "ssh-config"),
-                help="Path to runtime SSH config file.",
-            ),
             Argument(
                 names=("H", "hosts"),
                 help="Comma-separated host name(s) to execute tasks against.",
@@ -49,6 +45,15 @@ class Fab(Program):
                 kind=bool,
                 help="Request an upfront SSH key passphrase prompt.",
             ),
+            Argument(
+                names=("S", "ssh-config"),
+                help="Path to runtime SSH config file.",
+            ),
+            Argument(
+                names=("t", "connect-timeout"),
+                kind=int,
+                help="Specifies default connection timeout, in seconds.",
+            ),
         ]
         return core_args + my_args
 
@@ -120,6 +125,10 @@ class Fab(Program):
         path = self.args["identity"].value
         if path:
             connect_kwargs["key_filename"] = path
+        # Ditto for connect timeout
+        timeout = self.args["connect-timeout"].value
+        if timeout:
+            connect_kwargs["timeout"] = timeout
         # Secrets prompts that want to happen at handoff time instead of
         # later/at user-time.
         # TODO: should this become part of Invoke proper in case other
@@ -137,6 +146,14 @@ class Fab(Program):
         self.config.merge()
 
 
-program = Fab(
-    name="Fabric", version=fabric, executor_class=Executor, config_class=Config
-)
+# Mostly a concession to testing.
+def make_program():
+    return Fab(
+        name="Fabric",
+        version=fabric,
+        executor_class=Executor,
+        config_class=Config,
+    )
+
+
+program = make_program()
